@@ -8,7 +8,7 @@
 //
 // R_CoreArray.cpp: Export the C routines of CoreArray library
 //
-// Copyright (C) 2014-2022    Xiuwen Zheng
+// Copyright (C) 2014-2024    Xiuwen Zheng
 //
 // gdsfmt is free software: you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License Version 3 as
@@ -27,19 +27,19 @@
  *	\file     R_CoreArray.cpp
  *	\author   Xiuwen Zheng [zhengx@u.washington.edu]
  *	\version  1.0
- *	\date     2014 - 2022
+ *	\date     2014 - 2024
  *	\brief    Export the C routines of CoreArray library
  *	\details
 **/
 
 #define COREARRAY_GDSFMT_PACKAGE
 
-#include <R_GDS_CPP.h>
-#include <cstring>
-#include <R_ext/Rdynload.h>
 #include <vector>
 #include <map>
 #include <set>
+#include <cstring>
+#include <R_GDS_CPP.h>
+#include <R_ext/Rdynload.h>
 
 
 namespace gdsfmt
@@ -213,7 +213,7 @@ static void gdsfile_free(SEXP ptr_obj)
 		CORE_TRY
 			GDS_File_Close(file);
 		CORE_CATCH(has_error = true);
-		if (has_error) error(GDS_GetError());
+		if (has_error) error("%s", GDS_GetError());
 	}
 }
 
